pub fn load_csv_records(path: &Path) -> BehavioralFidelityResult<Vec<Record>>Expand description
Load all records from a CSV file. Header line is required and is used to pick the alias map.
pub fn load_csv_records(path: &Path) -> BehavioralFidelityResult<Vec<Record>>Load all records from a CSV file. Header line is required and is used to pick the alias map.