pub struct EvaluatorError(pub String);Expand description
Generic error wrapper so the iteration loop can propagate underlying engine + IO failures without the loop being tied to any one error type.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Debug for EvaluatorError
impl Debug for EvaluatorError
Sourceimpl Display for EvaluatorError
impl Display for EvaluatorError
Sourceimpl Error for EvaluatorError
impl Error for EvaluatorError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()