pub struct QualityGate {
pub name: String,
pub metric: QualityMetric,
pub threshold: f64,
pub upper_threshold: Option<f64>,
pub comparison: Comparison,
}Expand description
A single quality gate with a metric, threshold, and comparison.
Fields
name: StringHuman-readable name for this gate.
metric: QualityMetricThe metric to check.
threshold: f64Threshold value for comparison.
upper_threshold: Option<f64>Upper threshold for Between comparison.
comparison: ComparisonHow to compare the metric value against the threshold.
Implementations
Sourceimpl QualityGate
impl QualityGate
Sourcepub fn new(
name: impl Into<String>,
metric: QualityMetric,
threshold: f64,
comparison: Comparison,
) -> Self
pub fn new( name: impl Into<String>, metric: QualityMetric, threshold: f64, comparison: Comparison, ) -> Self
Create a new quality gate.
Sourcepub fn gte(
name: impl Into<String>,
metric: QualityMetric,
threshold: f64,
) -> Self
pub fn gte( name: impl Into<String>, metric: QualityMetric, threshold: f64, ) -> Self
Create a gate that requires metric >= threshold.
Sourcepub fn lte(
name: impl Into<String>,
metric: QualityMetric,
threshold: f64,
) -> Self
pub fn lte( name: impl Into<String>, metric: QualityMetric, threshold: f64, ) -> Self
Create a gate that requires metric <= threshold.